//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// December 13, 1999
//
// Launch netscape on a piece of SAS html documentation. Makes use of
// SAS_PATH.
//
#include "sashelp.h"

#include <errstr.h>
#include <param.h>
#include <Tracer.h>
#include <SasFileLocator.h>

#include <string>
#include <vector>

bool netscape(const std::string & url,
	      bool otherwindow = false,
	      bool remote = true){
  PROC
    // Invoke netscape on the given url. It can start a new window
    // (otherwindow = true), and it'll try to talk to an existing
    // netscape (remote = true) or start a new netscape process
    // (remote = false).
    // For a description of the commands that can be fed to netscape
    // see
    // http://home.netscape.com/newsref/std/x-remote.html
    
  string s = "";
  if(otherwindow)
    s = ", new-window";
  if(remote){
    errstr << "Trying to talk to a running Netscape ... ";
    if(system(string("netscape -raise -remote \"openURL(" + url
		     + s + ")\" 2> /dev/null").c_str())){
      errstr << "failed." << Sas::message(Msg::App, Msg::Always);
      errstr << "Trying to start netscape in the background ...";
      if(system(string("netscape " + url
		       + "&").c_str())){
	errstr << "failed again." << Sas::message(Msg::App, Msg::Always);
	ALTRETURNV(false)
	  }
    }
  } else {
    errstr << "Trying to start netscape in the background ...";
    if(system(string("netscape " + url
		     + "&").c_str())){
      errstr << "failed." << Sas::message(Msg::App, Msg::Always);
      ALTRETURNV(false)
	}
  }
  errstr << "ok." << Sas::message(Msg::App, Msg::Always);
  RETURN true;
}


void sashelp () {
  PROC
    // There are two types of html files:
    //   + <subdir of SAS_PATH>/doc/<something>.html
    //   + <subdir of SAS_PATH>/doc/<something>/index.html
  string s = stringParameter("doc");
  const string readmetarget = "README.html";
  const string toptarget = "doc/" + s + ".html";
  const string tasktarget = "doc/" + s + "/" + "index.html";
  string readmedoc = fileLocator.locate(readmetarget, "", false);
  string topdoc = fileLocator.locate(toptarget, "", false);
  string taskdoc = fileLocator.locate(tasktarget, "", false);
  const bool remote = booleanParameter("remote");
  const bool newwindow = booleanParameter("newwindow");
  if(topdoc.size() > 0){
    netscape("file://" + topdoc, newwindow, remote);
    if(taskdoc.size() > 0){
      clog << "Found two matching documents. Opening both of them." << endl;
      netscape("file://" + taskdoc, true, remote);
    }
  } else if(taskdoc.size() > 0) {
    netscape("file://" + taskdoc, newwindow, remote);
  } else if(readmedoc.size() > 0) {
    netscape("file://" + readmedoc, newwindow, remote);
  } else {
    errstr << "Could not find any suitable documentation."
	   << Sas::error("NoHtmlDocument");
  }
  ENDPROC
}
  
  
